@@ -1,8 +1,8 @@
 from abc import ABC, abstractmethod
 from enum import Enum
-from typing import List, Optional
+from typing import List, Optional, Iterable
 
-from bauh.api.constants import CACHE_PATH
+from bauh.api.paths import CACHE_DIR
 
 
 class CustomSoftwareAction:
@@ -11,7 +11,8 @@ class CustomSoftwareAction:
                  requires_root: bool, manager: "SoftwareManager" = None,
                  backup: bool = False, refresh: bool = True,
                  i18n_confirm_key: str = None,
-                 requires_internet: bool = False):
+                 requires_internet: bool = False,
+                 requires_confirmation: bool = True):
         """
         :param i18n_label_key: the i18n key that will be used to display the action name
         :param i18n_status_key: the i18n key that will be used to display the action name being executed
@@ -23,6 +24,7 @@ class CustomSoftwareAction:
         :param refresh: if the a full app refresh should be done if the action succeeds
         :param i18n_confirm_key: action confirmation message
         :param requires_internet: if the action requires internet connection to be executed
+        :param requires_confirmation: if a confirmation popup should be displayed to the user before calling the action
         """
         self.i18n_label_key = i18n_label_key
         self.i18n_status_key = i18n_status_key
@@ -34,6 +36,7 @@ class CustomSoftwareAction:
         self.refresh = refresh
         self.i18n_confirm_key = i18n_confirm_key
         self.requires_internet = requires_internet
+        self.requires_confirmation = requires_confirmation
 
     def __hash__(self):
         return self.i18n_label_key.__hash__() + self.i18n_status_key.__hash__() + self.manager_method.__hash__()
@@ -146,7 +149,7 @@ class SoftwarePackage(ABC):
         """
         :return: base cache path for the specific app type
         """
-        return CACHE_PATH + '/' + self.get_type()
+        return f'{CACHE_DIR}/{self.get_type()}'
 
     def can_be_updated(self) -> bool:
         """
@@ -199,7 +202,7 @@ class SoftwarePackage(ABC):
         """
         pass
 
-    def get_custom_supported_actions(self) -> List[CustomSoftwareAction]:
+    def get_custom_actions(self) -> Optional[Iterable[CustomSoftwareAction]]:
         """
         :return: custom supported actions
         """
