@@ -1,6 +1,6 @@
 from abc import ABC
 from enum import Enum
-from typing import List, Set, Optional
+from typing import List, Set, Optional, Dict
 
 
 class MessageType(Enum):
@@ -46,13 +46,14 @@ class InputOption:
 
     def __init__(self, label: str, value: object, tooltip: Optional[str] = None,
                  icon_path: Optional[str] = None, read_only: bool = False, id_: Optional[str] = None,
-                 invalid: bool = False):
+                 invalid: bool = False, extra_properties: Optional[Dict[str, str]] = None):
         """
         :param label: the string that will be shown to the user
         :param value: the option value (not shown)
         :param tooltip: an optional tooltip
         :param icon_path: an optional icon path
         :param invalid: if this option is considered invalid
+        :param extra_properties: extra properties
         """
         if not label:
             raise Exception("'label' must be a not blank string")
@@ -64,6 +65,7 @@ class InputOption:
         self.icon_path = icon_path
         self.read_only = read_only
         self.invalid = invalid
+        self.extra_properties = extra_properties
 
     def __hash__(self):
         return hash(self.label) + hash(self.value)
@@ -287,8 +289,8 @@ class TabGroupComponent(ViewComponent):
 
 class RangeInputComponent(InputViewComponent):
 
-    def __init__(self, id_: str, label: str, tooltip: str, min_value: float, max_value: float,
-                 step_value: float, value: float = None, max_width: int = None):
+    def __init__(self, id_: str, label: str, tooltip: str, min_value: int, max_value: int,
+                 step_value: int, value: Optional[int] = None, max_width: int = None):
         super(RangeInputComponent, self).__init__(id_=id_)
         self.label = label
         self.tooltip = tooltip
