@@ -20,9 +20,8 @@ from bauh.commons import system
 from bauh.commons.html import bold
 from bauh.commons.system import SimpleProcess, ProcessHandler
 from bauh.gems.web import ENV_PATH, NODE_DIR_PATH, NODE_BIN_PATH, NODE_MODULES_PATH, NATIVEFIER_BIN_PATH, \
-    ELECTRON_PATH, ELECTRON_DOWNLOAD_URL, ELECTRON_SHA256_URL, URL_ENVIRONMENT_SETTINGS, NPM_BIN_PATH, NODE_PATHS, \
-    nativefier, ELECTRON_WIDEVINE_URL, ELECTRON_WIDEVINE_SHA256_URL, \
-    ENVIRONMENT_SETTINGS_CACHED_FILE, ENVIRONMENT_SETTINGS_TS_FILE, get_icon_path, NATIVEFIER_BASE_URL
+    ELECTRON_CACHE_DIR, URL_ENVIRONMENT_SETTINGS, NPM_BIN_PATH, NODE_PATHS, \
+    nativefier, ENVIRONMENT_SETTINGS_CACHED_FILE, ENVIRONMENT_SETTINGS_TS_FILE, get_icon_path
 from bauh.gems.web.model import WebApplication
 from bauh.view.util.translation import I18n
 
@@ -49,49 +48,49 @@ class EnvironmentUpdater:
         self.task_read_settings_id = 'web_read_settings'
         self.taskman = taskman
 
-    def _download_and_install(self, version: str, version_url: str, watcher: ProcessWatcher) -> bool:
-        self.logger.info("Downloading NodeJS {}: {}".format(version, version_url))
+    def _install_nodejs(self, version: str, version_url: str, watcher: ProcessWatcher) -> bool:
+        self.logger.info(f"Downloading NodeJS {version}: {version_url}")
 
-        tarf_path = '{}/{}'.format(ENV_PATH, version_url.split('/')[-1])
+        tarf_path = f"{ENV_PATH}/{version_url.split('/')[-1]}"
         downloaded = self.file_downloader.download(version_url, watcher=watcher, output_path=tarf_path, cwd=ENV_PATH)
 
         if not downloaded:
-            self.logger.error("Could not download '{}'. Aborting...".format(version_url))
+            self.logger.error(f"Could not download '{version_url}'. Aborting...")
             return False
         else:
             try:
                 tf = tarfile.open(tarf_path)
                 tf.extractall(path=ENV_PATH)
 
-                extracted_file = '{}/{}'.format(ENV_PATH, tf.getnames()[0])
+                extracted_file = f'{ENV_PATH}/{tf.getnames()[0]}'
 
                 if os.path.exists(NODE_DIR_PATH):
-                    self.logger.info("Removing old NodeJS version installation dir -> {}".format(NODE_DIR_PATH))
+                    self.logger.info(f"Removing old NodeJS version installation dir -> {NODE_DIR_PATH}")
                     try:
                         shutil.rmtree(NODE_DIR_PATH)
                     except:
-                        self.logger.error("Could not delete old NodeJS version dir -> {}".format(NODE_DIR_PATH))
+                        self.logger.error(f"Could not delete old NodeJS version dir -> {NODE_DIR_PATH}")
                         traceback.print_exc()
                         return False
 
                 try:
                     os.rename(extracted_file, NODE_DIR_PATH)
                 except:
-                    self.logger.error("Could not rename the NodeJS version file {} as {}".format(extracted_file, NODE_DIR_PATH))
+                    self.logger.error(f"Could not rename the NodeJS version file {extracted_file} as {NODE_DIR_PATH}")
                     traceback.print_exc()
                     return False
 
                 if os.path.exists(NODE_MODULES_PATH):
-                    self.logger.info('Deleting {}'.format(NODE_MODULES_PATH))
+                    self.logger.info(f'Deleting {NODE_MODULES_PATH}')
                     try:
                         shutil.rmtree(NODE_MODULES_PATH)
                     except:
-                        self.logger.error("Could not delete the directory {}".format(NODE_MODULES_PATH))
+                        self.logger.error(f"Could not delete the directory {NODE_MODULES_PATH}")
                         return False
 
                 return True
             except:
-                self.logger.error('Could not extract {}'.format(tarf_path))
+                self.logger.error(f'Could not extract {tarf_path}')
                 traceback.print_exc()
                 return False
             finally:
@@ -99,13 +98,13 @@ class EnvironmentUpdater:
                     try:
                         os.remove(tarf_path)
                     except:
-                        self.logger.error('Could not delete file {}'.format(tarf_path))
+                        self.logger.error(f'Could not delete file {tarf_path}')
 
     def check_node_installed(self, version: str) -> bool:
         if not os.path.exists(NODE_DIR_PATH):
             return False
         else:
-            installed_version = system.run_cmd('{} --version'.format(NODE_BIN_PATH), print_error=False)
+            installed_version = system.run_cmd(f'{NODE_BIN_PATH} --version', print_error=False)
 
             if installed_version:
                 installed_version = installed_version.strip()
@@ -113,7 +112,7 @@ class EnvironmentUpdater:
                 if installed_version.startswith('v'):
                     installed_version = installed_version[1:]
 
-                self.logger.info('Node versions: installed ({}), cloud ({})'.format(installed_version, version))
+                self.logger.info(f'Node versions: installed ({installed_version}), cloud ({version})')
 
                 if version != installed_version:
                     self.logger.info("The NodeJs installed version is different from the Cloud.")
@@ -129,7 +128,7 @@ class EnvironmentUpdater:
         Path(ENV_PATH).mkdir(parents=True, exist_ok=True)
 
         if not os.path.exists(NODE_DIR_PATH):
-            return self._download_and_install(version=version, version_url=version_url, watcher=watcher)
+            return self._install_nodejs(version=version, version_url=version_url, watcher=watcher)
         else:
             installed_version = system.run_cmd('{} --version'.format(NODE_BIN_PATH), print_error=False)
 
@@ -139,27 +138,27 @@ class EnvironmentUpdater:
                 if installed_version.startswith('v'):
                     installed_version = installed_version[1:]
 
-                self.logger.info('Node versions: installed ({}), cloud ({})'.format(installed_version, version))
+                self.logger.info(f'Node versions: installed ({installed_version}), cloud ({version})')
 
                 if version != installed_version:
                     self.logger.info("The NodeJs installed version is different from the Cloud.")
-                    return self._download_and_install(version=version, version_url=version_url, watcher=watcher)
+                    return self._install_nodejs(version=version, version_url=version_url, watcher=watcher)
                 else:
                     self.logger.info("Node is already up to date")
                     return True
             else:
                 self.logger.warning("Could not determine the current NodeJS installed version")
-                self.logger.info("Removing {}".format(NODE_DIR_PATH))
+                self.logger.info(f"Removing {NODE_DIR_PATH}")
                 try:
                     shutil.rmtree(NODE_DIR_PATH)
-                    return self._download_and_install(version=version, version_url=version_url, watcher=watcher)
+                    return self._install_nodejs(version=version, version_url=version_url, watcher=watcher)
                 except:
-                    self.logger.error('Could not delete the dir {}'.format(NODE_DIR_PATH))
+                    self.logger.error(f'Could not delete the dir {NODE_DIR_PATH}')
                     return False
 
     def _install_node_lib(self, name: str, version: str, handler: ProcessHandler):
-        lib_repr = '{}{}'.format(name, '@{}'.format(version) if version else '')
-        self.logger.info("Installing {}".format(lib_repr))
+        lib_repr = f"{name}{'@{}'.format(version) if version else ''}"
+        self.logger.info(f"Installing {lib_repr}")
 
         if handler and handler.watcher:
             handler.watcher.change_substatus(self.i18n['web.environment.install'].format(bold(lib_repr)))
@@ -169,15 +168,15 @@ class EnvironmentUpdater:
         installed = handler.handle_simple(proc)[0]
 
         if installed:
-            self.logger.info("{} successfully installed".format(lib_repr))
+            self.logger.info(f"{lib_repr} successfully installed")
 
         return installed
 
     def _install_nativefier(self, version: str, url: str, handler: ProcessHandler) -> bool:
-        self.logger.info("Checking if nativefier@{} exists".format(version))
+        self.logger.info(f"Checking if nativefier@{version} exists")
 
         if not url or not self.http_client.exists(url):
-            self.logger.warning("The file {} seems not to exist".format(url))
+            self.logger.warning(f"The file {url} seems not to exist")
             handler.watcher.show_message(title=self.i18n['message.file.not_exist'],
                                          body=self.i18n['message.file.not_exist.body'].format(bold(url)),
                                          type_=MessageType.ERROR)
@@ -191,79 +190,28 @@ class EnvironmentUpdater:
     def _is_nativefier_installed(self) -> bool:
         return os.path.exists(NATIVEFIER_BIN_PATH)
 
-    def download_electron(self, version: str, url: str, widevine: bool, watcher: ProcessWatcher) -> bool:
-        Path(ELECTRON_PATH).mkdir(parents=True, exist_ok=True)
-        self.logger.info("Downloading Electron {}".format(version))
+    def _get_electron_url(self, version: str, base_url: str, is_x86_x64_arch: bool) -> str:
+        return base_url.format(version=version, arch='x64' if is_x86_x64_arch else 'ia32')
 
-        electron_path = self._get_electron_file_path(url=url, relative=False)
-
-        if not self.http_client.exists(url):
-            self.logger.warning("The file {} seems not to exist".format(url))
-            watcher.show_message(title=self.i18n['message.file.not_exist'],
-                                 body=self.i18n['message.file.not_exist.body'].format(bold(url)),
-                                 type_=MessageType.ERROR)
-            return False
-
-        return self.file_downloader.download(file_url=url, watcher=watcher, output_path=electron_path, cwd=ELECTRON_PATH)
-
-    def download_electron_sha256(self, version: str, url: str, widevine: bool, watcher: ProcessWatcher) -> bool:
-        self.logger.info("Downloading Electron {} sha526".format(version))
-
-        sha256_path = self._get_electron_file_path(url=url, relative=False)
-
-        if not self.http_client.exists(url):
-            self.logger.warning("The file {} seems not to exist".format(url))
-            watcher.show_message(title=self.i18n['message.file.not_exist'],
-                                 body=self.i18n['message.file.not_exist.body'].format(bold(url)),
-                                 type_=MessageType.ERROR)
-            return False
-
-        return self.file_downloader.download(file_url=url, watcher=watcher, output_path=sha256_path, cwd=ELECTRON_PATH)
-
-    def _get_electron_url(self, version: str, is_x86_x64_arch: bool, widevine: bool) -> str:
-        arch = 'x64' if is_x86_x64_arch else 'ia32'
-        if widevine:
-            return ELECTRON_WIDEVINE_URL.format(version=version, arch=arch)
-        else:
-            return ELECTRON_DOWNLOAD_URL.format(version=version, arch=arch)
-
-    def _get_electron_sha256_url(self, version: str, widevine: bool) -> str:
-        if widevine:
-            return ELECTRON_WIDEVINE_SHA256_URL.format(version=version)
-        else:
-            return ELECTRON_SHA256_URL.format(version=version)
-
-    def _get_electron_file_path(self, url: str, relative: bool) -> str:
-        file_path = url.replace(':', '').replace('/', '') + '/' + url.split('/')[-1]
-        return '{}/{}'.format(ELECTRON_PATH, file_path) if not relative else file_path
-
-    def check_electron_installed(self, version: str, is_x86_x64_arch: bool, widevine: bool) -> Dict[str, bool]:
-        self.logger.info("Checking if Electron {} (widevine={}) is installed".format(version, widevine))
+    def check_electron_installed(self, version: str, base_url: str, is_x86_x64_arch: bool, widevine: bool) -> Dict[str, bool]:
+        self.logger.info(f"Checking if Electron {version} (widevine={widevine}) is installed")
         res = {'electron': False, 'sha256': False}
 
-        if not os.path.exists(ELECTRON_PATH):
-            self.logger.info("The Electron folder {} was not found".format(ELECTRON_PATH))
+        if not os.path.exists(ELECTRON_CACHE_DIR):
+            self.logger.info(f"Electron cache directory {ELECTRON_CACHE_DIR} not found")
         else:
-            files = {f.split(ELECTRON_PATH + '/')[1] for f in glob.glob(ELECTRON_PATH + '/**', recursive=True) if os.path.isfile(f)}
+            files = {os.path.basename(f) for f in glob.glob(f'{ELECTRON_CACHE_DIR}/**', recursive=True) if os.path.isfile(f)}
 
             if files:
-                electron_url = self._get_electron_url(version, is_x86_x64_arch, widevine)
-                file_path = self._get_electron_file_path(url=electron_url, relative=True)
-
-                res['electron'] = file_path in files
-
-                if not res['electron']:
-                    res['sha256'] = True
-                else:
-                    sha_url = self._get_electron_sha256_url(version=version, widevine=widevine)
-                    sha_path = self._get_electron_file_path(url=sha_url, relative=True)
-                    res['sha256'] = sha_path in files
+                electron_url = self._get_electron_url(version=version, base_url=base_url, is_x86_x64_arch=is_x86_x64_arch)
+                res['electron'] = os.path.basename(electron_url) in files
+                res['sha256'] = res['electron']
             else:
-                self.logger.info('No Electron file found in {}'.format(ELECTRON_PATH))
+                self.logger.info(f"No Electron file found in '{ELECTRON_CACHE_DIR}'")
 
             for att in ('electron', 'sha256'):
                 if res[att]:
-                    self.logger.info('{} ({}) already downloaded'.format(att, version))
+                    self.logger.info(f'{att} ({version}) already downloaded')
 
         return res
 
@@ -276,7 +224,7 @@ class EnvironmentUpdater:
         try:
             settings_exp = int(web_config['environment']['cache_exp'])
         except ValueError:
-            self.logger.error("Could not parse settings property 'environment.cache_exp': {}".format(web_config['environment']['cache_exp']))
+            self.logger.error(f"Could not parse settings property 'environment.cache_exp': {web_config['environment']['cache_exp']}")
             return True
 
         if settings_exp <= 0:
@@ -299,7 +247,7 @@ class EnvironmentUpdater:
         try:
             env_timestamp = datetime.fromtimestamp(float(env_ts_str))
         except:
-            self.logger.error("Could not parse environment settings file timestamp: {}".format(env_ts_str))
+            self.logger.error(f"Could not parse environment settings file timestamp: {env_ts_str}")
             return True
 
         expired = env_timestamp + timedelta(hours=settings_exp) <= datetime.utcnow()
@@ -319,7 +267,7 @@ class EnvironmentUpdater:
             try:
                 return yaml.safe_load(cached_settings_str)
             except yaml.YAMLError:
-                self.logger.error('Could not parse the cache environment settings file: {}'.format(cached_settings_str))
+                self.logger.error(f'Could not parse the cache environment settings file: {cached_settings_str}')
 
     def read_settings(self, web_config: dict, cache: bool = True) -> Optional[dict]:
         if self.taskman:
@@ -345,8 +293,13 @@ class EnvironmentUpdater:
 
             try:
                 settings = yaml.safe_load(res.content)
+                nodejs_settings = settings.get('nodejs')
+
+                if nodejs_settings:
+                    nodejs_settings['url'] = nodejs_settings['url'].format(version=nodejs_settings['version'])
+
             except yaml.YAMLError:
-                self.logger.error('Could not parse environment settings: {}'.format(res.text))
+                self.logger.error(f'Could not parse environment settings: {res.text}')
                 self._finish_task_download_settings()
                 return
 
@@ -356,7 +309,7 @@ class EnvironmentUpdater:
             try:
                 Path(cache_dir).mkdir(parents=True, exist_ok=True)
             except OSError:
-                self.logger.error("Could not create Web cache directory: {}".format(cache_dir))
+                self.logger.error(f"Could not create Web cache directory: {cache_dir}")
                 self.logger.info('Finished')
                 self._finish_task_download_settings()
                 return
@@ -377,19 +330,22 @@ class EnvironmentUpdater:
             return
 
     def _check_and_fill_electron(self, pkg: WebApplication, env: dict, local_config: dict, x86_x64: bool, widevine: bool, output: List[EnvironmentComponent]):
-        electron_version = env['electron-wvvmp' if widevine else 'electron']['version']
+        electron_settings = env['electron-wvvmp' if widevine else 'electron']
+        electron_version = electron_settings['version']
 
         if not widevine and pkg.version and pkg.version != electron_version:  # this feature does not support custom widevine electron at the moment
-            self.logger.info('A preset Electron version is defined for {}: {}'.format(pkg.url, pkg.version))
+            self.logger.info(f'A preset Electron version is defined for {pkg.url}: {pkg.version}')
             electron_version = pkg.version
 
         if not widevine and local_config['environment']['electron']['version']:
-            self.logger.warning("A custom Electron version will be used {} to install {}".format(electron_version, pkg.url))
+            self.logger.warning(f"A custom Electron version will be used {electron_version} to install {pkg.url}")
             electron_version = local_config['environment']['electron']['version']
 
-        electron_status = self.check_electron_installed(version=electron_version, is_x86_x64_arch=x86_x64, widevine=widevine)
+        electron_status = self.check_electron_installed(version=electron_version, base_url=electron_settings['url'],
+                                                        is_x86_x64_arch=x86_x64, widevine=widevine)
+
+        electron_url = self._get_electron_url(version=electron_version, base_url=electron_settings['url'], is_x86_x64_arch=x86_x64)
 
-        electron_url = self._get_electron_url(version=electron_version, is_x86_x64_arch=x86_x64, widevine=widevine)
         output.append(EnvironmentComponent(name=electron_url.split('/')[-1],
                                            version=electron_version,
                                            url=electron_url,
@@ -398,7 +354,7 @@ class EnvironmentUpdater:
                                            update=not electron_status['electron'],
                                            properties={'widevine': widevine}))
 
-        sha_url = self._get_electron_sha256_url(version=electron_version, widevine=widevine)
+        sha_url = electron_settings['sha_url'].format(version=electron_version)
 
         output.append(EnvironmentComponent(name=sha_url.split('/')[-1],
                                            version=electron_version,
@@ -427,7 +383,7 @@ class EnvironmentUpdater:
 
     def _check_nativefier_installed(self, nativefier_settings: dict) -> bool:
         if not os.path.exists(NODE_MODULES_PATH):
-            self.logger.info('Node modules path {} not found'.format(NODE_MODULES_PATH))
+            self.logger.info(f'Node modules path {NODE_MODULES_PATH} not found')
             return False
         else:
             if not self._is_nativefier_installed():
@@ -438,7 +394,7 @@ class EnvironmentUpdater:
             if installed_version:
                 installed_version = installed_version.strip()
 
-            self.logger.info("Nativefier versions: installed ({}), cloud ({})".format(installed_version, nativefier_settings['version']))
+            self.logger.info(f"Nativefier versions: installed ({installed_version}), cloud ({nativefier_settings['version']})")
 
             if nativefier_settings['version'] != installed_version:
                 self.logger.info("Installed nativefier version is different from cloud's. Changing version.")
@@ -448,13 +404,8 @@ class EnvironmentUpdater:
             return True
 
     def _map_nativefier_file(self, nativefier_settings: dict) -> EnvironmentComponent:
-        base_url = nativefier_settings.get('url')
-        if not base_url:
-            self.logger.warning("'url' not found in nativefier environment settings. Using hardcoded URL '{}'".format(NATIVEFIER_BASE_URL))
-            base_url = NATIVEFIER_BASE_URL
-
-        url = base_url.format(version=nativefier_settings['version'])
-        return EnvironmentComponent(name='nativefier@{}'.format(nativefier_settings['version']),
+        url = nativefier_settings['url'].format(version=nativefier_settings['version'])
+        return EnvironmentComponent(name=f"nativefier@{nativefier_settings['version']}",
                                     url=url,
                                     size=self.http_client.get_content_length(url),
                                     version=nativefier_settings['version'],
@@ -462,17 +413,13 @@ class EnvironmentUpdater:
 
     def check_environment(self, env: dict, local_config: dict, app: WebApplication,
                           is_x86_x64_arch: bool, widevine: bool) -> List[EnvironmentComponent]:
-        """
-        :param app:
-        :param is_x86_x64_arch:
-        :return: the environment settings
-        """
+
         components, check_threads = [], []
 
         system_env = local_config['environment'].get('system', False)
 
         if system_env:
-            self.logger.warning("Using system's nativefier to install {}".format(app.url))
+            self.logger.warning(f"Using system's nativefier to install {app.url}")
         else:
             node_check = Thread(target=self._check_and_fill_node, args=(env, components))
             node_check.start()
@@ -497,7 +444,7 @@ class EnvironmentUpdater:
         nativefier_data = comp_map.get('nativefier')
 
         if node_data:
-            if not self._download_and_install(version=node_data.version, version_url=node_data.url, watcher=handler.watcher):
+            if not self._install_nodejs(version=node_data.version, version_url=node_data.url, watcher=handler.watcher):
                 return False
 
             if not self._install_nativefier(version=nativefier_data.version, url=nativefier_data.url, handler=handler):
@@ -506,17 +453,5 @@ class EnvironmentUpdater:
             if nativefier_data and not self._install_nativefier(version=nativefier_data.version, url=nativefier_data.url, handler=handler):
                 return False
 
-        electron_data = comp_map.get('electron')
-
-        if electron_data:
-            if not self.download_electron(version=electron_data.version, url=electron_data.url, watcher=handler.watcher, widevine=electron_data.properties['widevine']):
-                return False
-
-        sha256_data = comp_map.get('electron_sha256')
-
-        if sha256_data:
-            if not self.download_electron_sha256(version=sha256_data.version, url=sha256_data.url, watcher=handler.watcher, widevine=sha256_data.properties['widevine']):
-                return False
-
         self.logger.info('Environment successfully updated')
         return True
